@@ -1,6 +1,6 @@
 package Arepa;
 
-our $VERSION = 0.76;
+our $VERSION = 0.80;
 our $AREPA_MASTER_USER = 'arepa-master';
 
 1;
@@ -103,24 +103,28 @@ binNMUs triggers, you can go ahead to the next section.
 =head2 CONFIGURE REPOSITORY
 
 Once you have a clear idea of the distributions you want, you have to
-configure the reprepro repository. Open
-C</var/arepa/repository/conf/distributions>. It will look something like this:
+register them into your repository. To do that, simply call C<arepa-admin>
+with the codename as first parameter and suite as second parameter (optional).
+By default it will create a distribution with one component C<main> and two
+architectures (C<source> and the current architecture as reported by
+C<dpkg-architecture -qDEB_BUILD_ARCH>). You can change those defaults, and
+even add new fields (like C<AlsoAcceptFor> and similar, see the C<reprepro>
+manpage):
 
- Codename: squeeze
- Components: main
- Architectures: source amd64
- Suite: unstable
+ arepa-admin createdistribution mysqueeze
+ arepa-admin createdistribution --arch "amd64 source" mysqueeze
+ arepa-admin createdistribution --components "main contrib" mysqueeze
+ arepa-admin createdistribution --extra-field version:5.0 mysqueeze
 
-You need one of these stanzas for every distribution (separated by a blank
-line). The C<Codename> should be the distribution name, and you can specify
+This will update both C</var/arepa/repository/conf/distributions> and the
+repository itself (by calling C<reprepro export>).
+
+Note that the C<Codename> should be the distribution name, and you can specify
 the first alias as the C<Suite>. The rest of the aliases you can specify in a
 field C<AlsoAcceptFor>, like so:
 
- Codename: mysqueeze
- Components: main
- Architectures: source amd64
- Suite: unstable
- AlsoAcceptFor: squeeze, stable
+ arepa-admin createdistribution --extra-field "alsoacceptfor:squeeze stable" \
+                                mysqueeze
 
 Now, make sure you have GPG key for the special user C<arepa-master>. That
 will be the GPG key used to sign the repository. To do so, simply type:
@@ -128,14 +132,15 @@ will be the GPG key used to sign the repository. To do so, simply type:
  # su - arepa-master
  $ gpg --gen-key
 
-And follow the instructions.
+And follow the instructions. Make sure that key B<doesn't> have a passphrase.
 
 =head2 CONFIGURE WEB UI
 
 The next step is to configure the web interface. Make sure that you can access
 the application from the URL path C</arepa/arepa.cgi> and that it works
-properly. If you have installed the Debian package, everything should be
-already in place, and the only step you should follow is:
+properly. You have a sample configuration file in C<apache.conf>. If you have
+installed the Debian package, everything should be already in place, and the
+only step you should follow is:
 
  # a2ensite arepa
 
@@ -154,12 +159,18 @@ hashed with MD5. For example, you can use:
 =item
 
 Configure your C<sudo> so users in the group C<arepa> can execute
-C</usr/bin/arepa-sign>.
+C</usr/bin/arepa sign>, C</usr/bin/arepa sync> and C</usr/bin/arepa issynced>.
+You can add these lines in C<visudo>:
+
+ %arepa ALL = (arepa-master) NOPASSWD: /usr/bin/arepa sign
+ %arepa ALL = (arepa-master) NOPASSWD: /usr/bin/arepa sync
+ %arepa ALL = (arepa-master) NOPASSWD: /usr/bin/arepa issynced
 
 =item
 
-Add the keys of the developers that will upload packages to the keyring
-C</var/arepa/keyrings/uploaders.gpg>
+Add the keys of the developers that will upload packages to the uploader
+keyring (C</var/arepa/keyrings/uploaders.gpg>). You can do that in the web
+interface itself.
 
 =back
 
@@ -192,8 +203,8 @@ that the C</etc/apt/sources.list> is correct.
 
 B<IMPORTANT WARNING NOTE:> once you have created a builder chroot, it will
 automatically bind certain files (C</etc/passwd> and others) from the "host"
-machine. So, if you C<rm -rf> the chroot, you'll delete C</etc/passwd> in your
-machine. Make sure you "uninit" the builder first:
+machine. So, if you C<rm -rf> the chroot, B<<< you'll delete C</etc/passwd>
+>>> in your machine. Make sure you "uninit" the builder first:
 
  arepa-admin uninit squeezebuilder
 
